"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const command_1 = require("@oclif/command");
const conf_1 = tslib_1.__importDefault(require("conf"));
const fbjs_1 = require("@makepad/fbjs");
const inquirer = tslib_1.__importStar(require("inquirer"));
class GroupsGetPosts extends command_1.Command {
    async run() {
        const { flags } = this.parse(GroupsGetPosts);
        const config = new conf_1.default();
        const parsedIds = flags.ids.split(',');
        if (parsedIds.filter((id) => {
            return isNaN(parseInt(id, 10));
        }).length !== 0) {
            this.error('ids should be comma separated integers');
        }
        this.log(`Running in headless mode ? ${flags.headfull}`);
        const fb = await fbjs_1.FB.init({
            output: flags.output,
            debug: flags.debug,
            groupIds: parsedIds,
            disableAssets: true,
            headless: !flags.headfull,
            useCookies: true,
        }, flags.cookiePath);
        if (flags.cookiePath === undefined && !flags.public) {
            if (config.has('username') && config.has('password')) {
                try {
                    await fb.login(config.get('username'), config.get('password'));
                }
                catch (_a) {
                    const authCode = (await inquirer.prompt({
                        name: 'authCode',
                        type: 'input',
                        message: 'Two factor authentication detected. Please enter the authentication code',
                    })).authCode;
                    await fb.enterAuthCode(authCode);
                }
            }
        }
        for (let i = 0; i < parsedIds.length; i++) {
            // eslint-disable-next-line no-await-in-loop
            await fb.getGroupPosts(Number(parsedIds[i]), undefined);
        }
        await fb.close();
    }
}
exports.default = GroupsGetPosts;
GroupsGetPosts.description = 'describe the command here';
GroupsGetPosts.flags = {
    help: command_1.flags.help({ char: 'h' }),
    debug: command_1.flags.boolean({ description: 'Indicates the development environment', default: false }),
    headfull: command_1.flags.boolean({ description: 'Indicates the not headless mode', default: false }),
    concurrent: command_1.flags.integer({ char: 'c', default: 1, description: 'Number of concurrent jobs' }),
    ids: command_1.flags.string({ char: 'i', required: true, description: 'Comma separated Facebook group ids' }),
    public: command_1.flags.boolean({ description: 'Indicates the public visibility to skip authentication process', required: false, default: false }),
    output: command_1.flags.string({ char: 'o', description: 'The output path to save output posts', default: process.cwd() }),
    format: command_1.flags.enum({ description: 'The format of parsed files', options: ['json', 'csv', 'tsv'], default: 'json' }),
    cookiePath: command_1.flags.string({ description: 'The JSON file path for cookies to use. This will skip the authentication process' }),
};
GroupsGetPosts.args = [];
